@@ -51,9 +51,9 @@ if ($resty->has_model('Post')) {
         {
             description => "Blog post",
             columns => [
-                { name => 'title', label => 'Post title' },
-                { name => 'content', label => 'Post content' },
-                { name => 'author', label => 'Post author' },
+                { name => 'title', type => 'text', label => 'Post title' },
+                { name => 'content', type => 'text', label => 'Post content' },
+                { name => 'author', type => 'text', label => 'Post author' },
                 { name => 'created', default => ['now()'], type => 'timestamp(0) with time zone', label => 'Post creation time' },
                 { name => 'comments', label => 'Number of comments', type => "integer", default => 0 },
             ],
@@ -69,10 +69,10 @@ if ($resty->has_model('Comment')) {
         {
             description => "Blog comment",
             columns => [
-                { name => 'sender', label => 'Comment sender' },
-                { name => 'email', label => 'Sender email address' },
-                { name => 'url', label => 'Sender homepage URL' },
-                { name => 'body', label => 'Comment body' },
+                { name => 'sender', type => 'text', label => 'Comment sender' },
+                { name => 'email', type => 'text', label => 'Sender email address' },
+                { name => 'url', type => 'text', label => 'Sender homepage URL' },
+                { name => 'body', type => 'text', label => 'Comment body' },
                 { name => 'created', default => ['now()'], type => 'timestamp(0) with time zone', label => 'Comment creation time' },
                 { name => 'post', label => 'target post', type => 'integer' },
             ],
